; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = 
a = a
b = b
c = 
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| AI |-----------------------------------------------------
[Command]
name = "cpu1"
command = U, D, F
time = 1

[Command]
name = "cpu2"
command = U, B, F
time = 1

[Command]
name = "cpu3"
command = U, D, D
time = 1

[Command]
name = "cpu4"
command = F, B, U
time = 1

[Command]
name = "cpu5"
command = U, F, U, B
time = 1

[Command]
name = "cpu6"
command = U, D, B
time = 1

[Command]
name = "cpu7"
command = F, F, B
time = 1

[Command]
name = "cpu8"
command = U, D, U
time = 1

[Command]
name = "cpu9"
command = F, B, B
time = 1

[Command]
name = "cpu10"
command = F, F, B, B
time = 1

[Command]
name = "cpu11"
command = U, U, F
time = 1

[Command]
name = "cpu12"
command = U, B, B
time = 1

[Command]
name = "cpu13"
command = U, B, F, F
time = 1

[Command]
name = "cpu14"
command = U, F, B, U
time = 1

[Command]
name = "cpu15"
command = U, B, F, U
time = 1

[Command]
name = "cpu16"
command = U, B, B, B
time = 1

[Command]
name = "cpu17"
command = U, D, B, F
time = 1

[Command]
name = "cpu18"
command = U, D, B, D
time = 1

[Command]
name = "cpu19"
command = U, D, F, U
time = 1

[Command]
name = "cpu20"
command = U, D, U, B
time = 1

[Command]
name = "cpu21"
command = U, D, F, F
time = 1

[Command]
name = "cpu22"
command = F, F, F, F
time = 1

[Command]
name = "cpu23"
command = U, U, U, D
time = 1

[Command]
name = "cpu24"
command = B, B, B
time = 1

[Command]
name = "cpu25"
command = D, D, D, D
time = 1

[Command]
name = "cpu26"
command = D, D, D
time = 1

[Command]
name = "cpu27"
command = F, F, F
time = 1

[Command]
name = "cpu28"
command = U, U, U
time = 1

[Command]
name = "cpu29"
command = U, U, B, B
time = 1

[Command]
name = "cpu30"
command = D, D, F, F
time = 1


;-| Special Motions and Super Motion |------------------------------------------------------


[Command]
name = "Evade"
command = F, B, y
time = 20

[Command]
name = "Evade"
command = B, F, y
time = 20


[Command]
name = "Super 3 (Grab Special)"
command = ~D, DF, F, D, DF, F, x
time = 35

[Command]
name = "Super 2 (Explosion)"
command = ~D, DB, B, D, DB, B, a
time = 35

[Command]
name = "Super 1 (Fire Tornado)"
command = ~D, DF, F, D, DF, F, b
time = 35

[Command]
name = "Special 1 (Grab)"
command = ~D, DF, F, x
time = 20

[Command]
name = "Special 2 (Fire Stomp)"
command =  ~D, DB, B, a
time = 20

[Command]
name = "Special 3 (Fire Spin)"
command =  ~D, DF, F, b
time = 20

[Command]
name = "Grab 1"
command = /F, x+y
time = 20

[Command]
name = "Grab 2"
command = /F, a+b
time = 20

[Command]
name = "Jump Front Back Kick"
command = /F, b
time = 10

[Command]
name = "Jump Back Back Kick"
command = /B, b
time = 10

[Command]
name = "Jump Front Front Kick"
command = /F, a
time = 10

[Command]
name = "Jump Front2 Back Kick"
command = /B, a
time = 10

[Command]
name = "Crouch Back Front Punch"
command = /$DF, y
time = 10

[Command]
name = "Crouch Back Back Punch"
command = /$DB, y
time = 10

[Command]
name = "Crouch Front Front Punch"
command = /$DF, x
time = 10

[Command]
name = "Crouch Front Back Punch"
command = /$DB, x
time = 10

[Command]
name = "Crouch Back Front Kick"
command = /$DF, b
time = 10

[Command]
name = "Crouch Back Back Kick"
command = /$DB, b
time = 10

[Command]
name = "Crouch Front Front Kick"
command = /$DF, a
time = 10

[Command]
name = "Crouch Front Back Kick"
command = /$DB, a
time = 10

[Command]
name = "Standing Back Front Punch"
command = /F, y
time = 10

[Command]
name = "Standing Back Back Punch"
command = /B, y
time = 10

[Command]
name = "Standing Front Front Punch"
command = /F, x
time = 10

[Command]
name = "Standing Front Back Punch"
command = /B, x
time = 10

[Command]
name = "Standing Back Front Kick"
command = /F, b
time = 10

[Command]
name = "Standing Back Back Kick"
command = /B, b
time = 10

[Command]
name = "Standing Front Front Kick"
command = /F, a
time = 10

[Command]
name = "Standing Front Back Kick"
command = /B, a
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
[State -1, AI TRIGGER]
type = Varset
triggerall = RoundState = 2
trigger1 = command = "cpu1"
trigger2 = command = "cpu2"
trigger3 = command = "cpu3"
trigger4 = command = "cpu4"
trigger5 = command = "cpu5"
trigger6 = command = "cpu6"
trigger7 = command = "cpu7"
trigger8 = command = "cpu8"
trigger9 = command = "cpu9"
trigger10 = command = "cpu10"
trigger11 = command = "cpu11"
trigger12 = command = "cpu12"
trigger13 = command = "cpu13"
trigger14 = command = "cpu14"
trigger15 = command = "cpu15"
trigger16 = command = "cpu16"
trigger17 = command = "cpu17"
trigger18 = command = "cpu18"
trigger19 = command = "cpu19"
trigger20 = command = "cpu20"
trigger21 = command = "cpu21"
trigger22 = command = "cpu22"
trigger23 = command = "cpu23"
trigger24 = command = "cpu24"
trigger25 = command = "cpu25"
trigger26 = command = "cpu26"
trigger27 = command = "cpu27"
trigger28 = command = "cpu28"
trigger29 = command = "cpu29"
trigger30 = command = "cpu30"
v = 7
value = 1


[State -1, Super 3 (Grab Special)]
type = ChangeState
value = 6700
triggerall = command = "Super 3 (Grab Special)"
triggerall =  var (7) != 1
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = ctrl

[State -1, Super 3 (Grab Special) AI]
type = ChangeState
value = 6700
triggerall = var (7) = 1 && roundstate = 2
triggerall = !Win
triggerall = p2statetype != L
triggerall = p2statetype != A
triggerall = p2stateno != 5120
triggerall = p2stateno != 5121
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = P2BodyDist X = [10,30]
trigger1 = p2statetype != A
trigger1 = numenemy = 1
trigger1 = ctrl 
trigger1 = random <= 500

[State -1, Super 2 (Explosion)]
type = ChangeState
value = 6500
triggerall =  var (7) != 1
triggerall = command = "Super 2 (Explosion)"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl

[State -1, Super 2 (Explosion AI)]
type = ChangeState
value = 6500
triggerall = var (7) 
triggerall = !Win
triggerall = p2statetype != L
triggerall = power >= 2000
triggerall = statetype != A
triggerall = P2BodyDist X < 150
trigger1 = ctrl
trigger1 = random <= 50

[State -1, Super 1 (Fire Tornado)]
type = ChangeState
value = 6600
triggerall =  var (7) != 1
triggerall = command = "Super 1 (Fire Tornado)"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl

[State -1, Super 1 (Fire Tornado AI)]
type = ChangeState
value = 6600
triggerall =  var (7) 
triggerall =  !Win
triggerall = p2statetype != L
triggerall = power >= 1000
triggerall = statetype != A
triggerall = P2BodyDist X <= 30
trigger1 = ctrl
trigger1 = random <= 20

[State -1, Special 3 (Fire Spin)]
type = ChangeState
value = 5970
triggerall =  var (7) != 1
triggerall = command = "Special 3 (Fire Spin)"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact

[State -1, Special 3 (Fire Spin AI)]
type = ChangeState
value = 5970
triggerall =  var (7) 
triggerall =  !Win
triggerall = statetype = S
triggerall = statetype !=A
triggerall = P2BodyDist X <= 40
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact



[State -1, Special 2 (Fire Stomp)]
type = ChangeState
value = 5960
triggerall =  var (7) != 1
triggerall = command = "Special 2 (Fire Stomp)"
triggerall = statetype = S
trigger1 = ctrl

[State -1, Special 2 (Fire Stomp) AI]
type = ChangeState
value = 5960
triggerall =  var (7) 
triggerall =  !Win
triggerall = statetype = S
triggerall = statetype !=A
trigger1 = ctrl
trigger1 = random <= 110
trigger1 = p2statetype != L


[State -1, Special 1 (Grab)]
type = ChangeState
value = 5950
triggerall =  var (7) != 1
triggerall = command = "Special 1 (Grab)"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact


[State -1, Special 1 (Grab) AI]
type = ChangeState
value = 5950
triggerall =  var (7) 
triggerall =  !Win
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = P2BodyDist X = [0,30] 
triggerall = statetype = S
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact


; Evade
[State -1, Evade]
type = ChangeState
value = 6000
triggerall =  var (7) != 1
triggerall = (Command = "Evade")
trigger1 = (StateType = S) && (Ctrl)

; Evade
[State -1, Evade AI]
type = ChangeState
value = 6000
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = P2BodyDist x >= 25
trigger1 = (StateType = S) && (Ctrl)
trigger1 = random <= 150

[State -1, Grab 1]
type = ChangeState
value = 5800
triggerall =  var (7) != 1
triggerall = command = "Grab 1"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact

[State -1, Grab 1 AI]
type = ChangeState
value = 5800
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype = S
triggerall = P2BodyDist X = [0,30] 
triggerall = p2statetype != L
trigger1 = ctrl
trigger1 = random <= 50
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact

[State -1, Grab 2]
type = ChangeState
value = 5810
triggerall = var (7) != 1
triggerall = command = "Grab 2"
triggerall = statetype = S
triggerall = p2bodydist x = [0,40]
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact


[State -1, Grab 2 AI]
type = ChangeState
value = 5810
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype = S
triggerall = statetype != A
triggerall = P2Statetype != L
triggerall = p2bodydist x = [0,30]
trigger1 = ctrl
trigger1 = random <= 50
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact

[State -1, Jump Front Back Kick]
type = ChangeState
value = 5700
triggerall =  var (7) != 1
triggerall = command = "Jump Front Back Kick"
trigger1 = statetype = A
trigger1 = ctrl
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact

[State -1, Jump Front Back Kick AI]
type = ChangeState
value = 5700
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist x = [0,20]
triggerall = p2bodydist y = [0,30]
triggerall = P2statetype != L
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 15
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact


[State -1, Jump Back Back Kick]
type = ChangeState
value = 5701
triggerall =  var (7) != 1
triggerall = command = "Jump Back Back Kick"
trigger1 = statetype = A
trigger1 = ctrl
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact


[State -1, Jump Back Back Kick AI]
type = ChangeState
value = 5701
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != S 
triggerall = p2bodydist x = [0,20]
triggerall = p2bodydist y = [0,30]
triggerall = P2statetype != L
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 5
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact


[State -1, Jump Front Front Kick]
type = ChangeState
value = 5702
triggerall =  var (7) != 1
triggerall = command = "Jump Front Front Kick"
trigger1 = statetype = A
trigger1 = ctrl
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact

[State -1, Jump Front Front Kick AI]
type = ChangeState
value = 5702
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != S
triggerall = p2bodydist x = [0,20]
triggerall = p2bodydist y = [0,30] 
triggerall = P2statetype != L
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 5
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact

[State -1, Jump Front2 Back Kick]
type = ChangeState
value = 5703
triggerall =  var (7) != 1
triggerall = command = "Jump Front2 Back Kick"
trigger1 = statetype = A
trigger1 = ctrl
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact

[State -1, Jump Front2 Back Kick AI]
type = ChangeState
value = 5703
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist x = [0,20]
triggerall = p2bodydist y = [0,30]
triggerall = statetype != S 
triggerall = P2statetype != L
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 15
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact


; Crouch Back Front Punch
[State -1, Crouch Back Front Punch]
type = ChangeState
value = 5508
triggerall =  var (7) != 1
triggerall = command = "Crouch Back Front Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

; Crouch Back Front Punch AI
[State -1, Crouch Back Front Punch AI]
type = ChangeState
value = 5508
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,36]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Crouch Back Back Punch]
type = ChangeState
value = 5509
triggerall =  var (7) != 1
triggerall = command = "Crouch Back Back Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Back Back Punch AI]
type = ChangeState
value = 5509
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,36]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Crouch Front Front Punch]
type = ChangeState
value = 5510
triggerall =  var (7) != 1
triggerall = command = "Crouch Front Front Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Front Front Punch AI]
type = ChangeState
value = 5510
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,36]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Crouch Front Back Punch]
type = ChangeState
value = 5511
triggerall =  var (7) != 1
triggerall = command = "Crouch Front Back Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Crouch Front Back Punch AI]
type = ChangeState
value = 5511
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,40]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Back Front Kick]
type = ChangeState
value = 5512
triggerall =  var (7) != 1
triggerall = command = "Crouch Back Front Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Back Front Kick AI]
type = ChangeState
value = 5512
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,40]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Back Back Kick]
type = ChangeState
value = 5513
triggerall =  var (7) != 1
triggerall = command = "Crouch Back Back Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Back Back Kick AI]
type = ChangeState
value = 5513
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,40]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5513 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Front Front Kick]
type = ChangeState
value = 5514
triggerall =  var (7) != 1
triggerall = command = "Crouch Front Front Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5514 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Front Front Kick AI]
type = ChangeState
value = 5514
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,40]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5514 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Crouch Front Back Kick]
type = ChangeState
value = 5515
triggerall =  var (7) != 1
triggerall = command = "Crouch Front Back Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5514 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Crouch Front Back Kick AI]
type = ChangeState
value = 5515
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype != A
triggerall = p2bodydist X = [0,40]
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 40
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 18 || stateno = 5509 && time > 20 || stateno = 5510 && time > 20 || stateno = 5511 && time > 20) && movecontact
trigger5 = (stateno = 5512 && time > 18 || stateno = 5513 && time > 18 || stateno = 5514 && time > 18 || stateno = 5515 && time > 18) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Standing Back Front Punch
[State -1, Standing Back Front Punch]
type = ChangeState
value = 5500
triggerall =  var (7) != 1
triggerall = command = "Standing Back Front Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Back Front Punch AI]
type = ChangeState
value = 5500
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 200
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 18 || stateno = 5501 && time > 13  || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Back Back Punch]
type = ChangeState
value = 5501
triggerall =  var (7) != 1
triggerall = command = "Standing Back Back Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Back Back Punch AI]
type = ChangeState
value = 5501
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Standing Front Front Punch]
type = ChangeState
value = 5502
triggerall =  var (7) != 1
triggerall = command = "Standing Front Front Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Front Front Punch AI]
type = ChangeState
value = 5502
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact



[State -1, Standing Front Back Punch]
type = ChangeState
value = 5503
triggerall =  var (7) != 1
triggerall = command = "Standing Front Back Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Front Back Punch AI]
type = ChangeState
value = 5503
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Standing Back Front Kick]
type = ChangeState
value = 5504
triggerall =  var (7) != 1
triggerall = command = "Standing Back Front Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Back Front Kick AI]
type = ChangeState
value = 5504
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 13 || stateno = 5506 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact



[State -1, Standing Back Back Kick]
type = ChangeState
value = 5505
triggerall =  var (7) != 1
triggerall = command = "Standing Back Back Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Standing Back Back Kick AI]
type = ChangeState
value = 5505
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,20]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Standing Front Front Kick]
type = ChangeState
value = 5506
triggerall =  var (7) != 1
triggerall = command = "Standing Front Front Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Standing Front Front Kick AI]
type = ChangeState
value = 5506
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,23]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5507 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


[State -1, Standing Front Back Kick]
type = ChangeState
value = 5507
triggerall =  var (7) != 1
triggerall = command = "Standing Front Back Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5506 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact



[State -1, Standing Front Back Kick AI]
type = ChangeState
value = 5507
triggerall =  var (7)
triggerall =  !Win
triggerall = p2bodydist X = [0,23]
triggerall = p2statetype != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 400
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 15 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 16 || stateno = 5504 && time > 16 || stateno = 5505 && time > 16 || stateno = 5506 && time > 16) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


;===========================================================================
;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall =  var (7) != 1
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Taunt AI]
type = ChangeState
value = 195
triggerall =  var (7) 
triggerall =  !Win
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <=1

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall =  var (7) != 1
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 && time > 5 || stateno = 210 ||  stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Stand Light Punch AI]
type = ChangeState
value = 200
triggerall =  var (7)
triggerall =  !Win
triggerall = P2BodyDist x = [0,20]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 20
trigger2 = (stateno = 200 && time > 5 || stateno = 210 ||  stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall =  var (7) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 && time > 5 || stateno = 230 || stateno = 240  || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact


; Stand Medium Punch
[State -1, Stand Medium Punch AI]
type = ChangeState
value = 210
triggerall =  var (7)
triggerall =  !Win
triggerall = P2BodyDist x = [0,20]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = (stateno = 200 || stateno = 210 && time > 5 || stateno = 230 || stateno = 240  || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall =  var (7) != 1
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

[State -1, Stand Light Kick AI]
type = ChangeState
value = 230
triggerall =  var (7)
triggerall =  !Win
triggerall = P2BodyDist x = [0,20]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 10
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 && time > 5 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall =  var (7) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 && time > 5 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

; Standing Medium Kick
[State -1, Standing Medium Kick AI]
type = ChangeState
value = 240
triggerall =  var (7)
triggerall =  !Win
triggerall = P2BodyDist x = [0,20]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 10
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 && time > 5 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 && time > 5  || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410  && time > 5  || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 && time > 5 || stateno = 440) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 && time > 5) && movecontact
trigger3 = (stateno = 5500 && time > 13 || stateno = 5501 && time > 13 || stateno = 5502 && time > 14 || stateno = 5503 && time > 14 || stateno = 5504 && time > 14 || stateno = 5505 && time > 14 || stateno = 5506 && time > 15 || stateno = 5507 && time > 15) && movecontact
trigger4 = (stateno = 5508 && time > 13 || stateno = 5509 && time > 16 || stateno = 5510 && time > 16 || stateno = 5511 && time > 15) && movecontact
trigger5 = (stateno = 5512 && time > 13 || stateno = 5513 && time > 16 || stateno = 5514 && time > 16 || stateno = 5515 && time > 16) && movecontact
trigger6 = (stateno = 5907 && time > 16) && movecontact

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact
;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact


;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact
;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 12 || stateno = 610 && time > 12 || stateno = 630 && time > 12 || stateno = 640 && time > 12) && movecontact
trigger4 = (stateno = 5702 && time > 18 || stateno = 5700 && time > 18 || stateno = 5701 && time > 18) && movecontact
;---------------------------------------------------------------------------


